@@ -19,11 +19,11 @@ class IndianCalendarProvider : public AbstractCalendarProvider
     Q_OBJECT
 
 public:
-    explicit IndianCalendarProvider(QObject *parent, CalendarSystem::System calendarSystem);
+    explicit IndianCalendarProvider(QObject *parent, CalendarSystem::System calendarSystem, const QDate &startDate, const QDate &endDate);
     ~IndianCalendarProvider() override;
 
     QCalendar::YearMonthDay fromGregorian(const QDate &date) const override;
-    CalendarEvents::CalendarEventsPlugin::SubLabel subLabels(const QDate &date) const override;
+    CalendarEvents::CalendarEventsPlugin::SubLabel subLabel(const QDate &date) const override;
 
 private:
     const std::unique_ptr<class IndianCalendarProviderPrivate> d;
