@@ -12,15 +12,15 @@
 #include <QFormLayout>
 #include <QLineEdit>
 
-K_PLUGIN_FACTORY(DictionaryRunnerConfigFactory, registerPlugin<DictionaryRunnerConfig>();)
+K_PLUGIN_CLASS(DictionaryRunnerConfig)
 
-DictionaryRunnerConfig::DictionaryRunnerConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
+DictionaryRunnerConfig::DictionaryRunnerConfig(QObject *parent, const KPluginMetaData &metaData)
+    : KCModule(parent, metaData)
 {
     QFormLayout *layout = new QFormLayout;
     m_triggerWord = new QLineEdit;
     layout->addRow(i18nc("@label:textbox", "Trigger word:"), m_triggerWord);
-    setLayout(layout);
+    widget()->setLayout(layout);
     connect(m_triggerWord, &QLineEdit::textChanged, this, &DictionaryRunnerConfig::markAsChanged);
     load();
 }
@@ -30,9 +30,9 @@ void DictionaryRunnerConfig::load()
     KCModule::load();
     KSharedConfig::Ptr cfg = KSharedConfig::openConfig(QLatin1String("krunnerrc"));
     KConfigGroup grp = cfg->group("Runners");
-    grp = KConfigGroup(&grp, "Dictionary");
+    grp = KConfigGroup(&grp, KRUNNER_PLUGIN_NAME);
     m_triggerWord->setText(grp.readEntry(CONFIG_TRIGGERWORD, i18nc("Trigger word before word to define", "define")));
-    Q_EMIT changed(false);
+    setNeedsSave(false);
 }
 
 void DictionaryRunnerConfig::save()
@@ -40,17 +40,17 @@ void DictionaryRunnerConfig::save()
     KCModule::save();
     KSharedConfig::Ptr cfg = KSharedConfig::openConfig(QLatin1String("krunnerrc"));
     KConfigGroup grp = cfg->group("Runners");
-    grp = KConfigGroup(&grp, "Dictionary");
+    grp = KConfigGroup(&grp, KRUNNER_PLUGIN_NAME);
     grp.writeEntry(CONFIG_TRIGGERWORD, m_triggerWord->text());
     grp.sync();
-    Q_EMIT changed(false);
+    setNeedsSave(false);
 }
 
 void DictionaryRunnerConfig::defaults()
 {
     KCModule::defaults();
     m_triggerWord->setText(i18nc("Trigger word before word to define", "define"));
-    Q_EMIT changed(true);
+    setNeedsSave(true);
 }
 
 #include "dictionaryrunner_config.moc"
